@@ -21,12 +21,18 @@ from functools import partial
 from re import split, sub
 
 from feedparser import parse
-from httpx import AsyncClient
+from httpx import AsyncClient, Limits
 from loca import Loca
 from markdownify import markdownify as md
 from trio import open_nursery, run
 
 
+def truncate(string, length, end='…'):
+    """Return string truncated to length, ending with given character."""
+    if len(string) <= length: return string
+    return string[:length-len(end)] + end
+
+
 async def create(client, **note):
     """Create the given note and return its ID."""
     response = await client.post('notes/create', json=note)
@@ -42,12 +48,13 @@ async def post(job, client, link, title, summary):
                                                      'userId': job['user']})
     if search.json(): return
 
-    note = partial(create, client, i=job['token'], visibility='home', cw=title)
+    note = partial(create, client, i=job['token'], visibility='home',
+                   cw=truncate(title, job.getint('cw')))
     original = f'Original: {link}'
     rest = '\n\n'.join((*map(partial(sub, r'\s+', ' '),
                              split(r'\s*\n{2,}\s*', md(summary).strip())),
                         original))
-    limit = int(job['limit'])
+    limit = job.getint('text')
     parent = None
 
     while len(rest) > limit:
@@ -80,7 +87,8 @@ async def main():
         for section in config:
             if section == 'DEFAULT': continue
             job = config[section]
-            client = AsyncClient(base_url=job['dest'])
+            client = AsyncClient(base_url=job['dest'],
+                                 limits=Limits(max_connections=16))
             await stack.enter_async_context(client)
             nursery.start_soon(mirror, nursery, job, client)
 
